@@ -8,6 +8,7 @@
 
 #include <stdio.h>
 #include <ctype.h>
+#include <stdlib.h>
 
 #include "nest/bird.h"
 #include "lib/resource.h"
@@ -60,7 +61,7 @@ cmd_build_tree(void)
 	  if (!new)
 	    {
 	      int size = sizeof(struct cmd_node) + c-d;
-	      new = xmalloc(size);
+	      new = malloc(size);
 	      bzero(new, size);
 	      *old->plastson = new;
 	      old->plastson = &new->sibling;
@@ -314,7 +315,7 @@ cmd_expand(char *cmd)
       puts("No such command. Press `?' for help.");
       return NULL;
     }
-  b = xmalloc(strlen(n->cmd->command) + strlen(args) + 1);
+  b = malloc(strlen(n->cmd->command) + strlen(args) + 1);
   sprintf(b, "%s%s", n->cmd->command, args);
   return b;
 }
