@@ -20,7 +20,7 @@
 #include "lib/string.h"
 
 static inline u16
-get_u16(void *p)
+get_u16(const void *p)
 {
   u16 x;
   memcpy(&x, p, 2);
@@ -28,13 +28,22 @@ get_u16(void *p)
 }
 
 static inline u32
-get_u32(void *p)
+get_u32(const void *p)
 {
   u32 x;
   memcpy(&x, p, 4);
   return ntohl(x);
 }
 
+static inline u64
+get_u64(const void *p)
+{
+  u32 xh, xl;
+  memcpy(&xh, p, 4);
+  memcpy(&xl, p+4, 4);
+  return (((u64) ntohl(xh)) << 32) | ntohl(xl);
+}
+
 static inline void
 put_u16(void *p, u16 x)
 {
@@ -49,4 +58,14 @@ put_u32(void *p, u32 x)
   memcpy(p, &x, 4);
 }
 
+static inline void
+put_u64(void *p, u64 x)
+{
+  u32 xh, xl;
+  xh = htonl(x >> 32);
+  xl = htonl((u32) x);
+  memcpy(p, &xh, 4);
+  memcpy(p+4, &xl, 4);
+}
+
 #endif
