@@ -11,6 +11,9 @@ struct sym_show_data {
 	struct symbol	*sym;
 };
 
+struct f_inst;
+
 void cmd_show_status(void);
 void cmd_show_symbols(struct sym_show_data *sym);
 void cmd_show_memory(void);
+void cmd_eval(struct f_inst *expr);
