@@ -20,7 +20,8 @@ struct pipe_config {
 
 struct pipe_proto {
   struct proto p;
-  struct rtable *peer;
+  struct rtable *peer_table;
+  struct announce_hook *peer_ahook;	/* Announce hook for direction peer->primary */
   struct proto_stats peer_stats;	/* Statistics for the direction peer->primary */
   int mode;				/* PIPE_OPAQUE or PIPE_TRANSPARENT */
 };
@@ -31,10 +32,4 @@ extern struct protocol proto_pipe;
 static inline int proto_is_pipe(struct proto *p)
 { return p->proto == &proto_pipe; }
 
-static inline struct rtable * pipe_get_peer_table(struct proto *P)
-{ return ((struct pipe_proto *) P)->peer; }
-
-static inline struct proto_stats * pipe_get_peer_stats(struct proto *P)
-{ return &((struct pipe_proto *) P)->peer_stats; }
-
 #endif
