@@ -34,6 +34,12 @@ extern bird_clock_t now; 		/* Relative, monotonic time in seconds */
 extern bird_clock_t now_real;		/* Time in seconds since fixed known epoch */
 extern bird_clock_t boot_time;
 
+static inline int
+tm_active(timer *t)
+{
+  return t->expires != 0;
+}
+
 static inline bird_clock_t
 tm_remains(timer *t)
 {
